@@ -1,5 +1,5 @@
 package Bot::Cobalt::Conf;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 ## Bot::Cobalt::Conf
 ## Looks for the following YAML confs:
@@ -116,8 +116,8 @@ sub _read_core_channels_conf {
 
     CHAN: for my $channel (keys %$ctxt_cfg) {
       unless (ref $ctxt_cfg->{$channel} eq 'HASH') {
-        warn "Conf; channels.conf; ",
-          "cfg for $channel on $context is not a hash\n";
+#        warn "Conf; channels.conf; ",
+#          "cfg for $channel on $context is not a hash\n";
         $ctxt_cfg->{$channel} = {};
       }
     } ## CHAN
