@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC::Event;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 ## Base class for IRC events.
 
@@ -28,31 +28,42 @@ has 'src'     => (
     my %pieces;
     @pieces{@types} = parse_user($value);
     
-    for (@types) {
-      my $meth    = '_set_src_'.$_;
-      my $hasmeth = 'has_src_'.$_;
-      $self->$meth($pieces{$_})
-        if $self->$hasmeth;
+    for my $type (@types) {
+      my $meth    = '_set_src_'.$type;
+      my $hasmeth = 'has_src_'.$type;
+      $self->$meth($pieces{$type}) if $self->$hasmeth;
     }
   }
 );
 
-has 'src_nick' => (  is => 'ro', lazy => 1,
-  default   => sub { (parse_user($_[0]->src))[0] },
+has 'src_nick' => (  
+  lazy => 1,
+
+  is  => 'rwp',
+  
   predicate => 'has_src_nick',
-  writer    => '_set_src_nick',
+
+  default   => sub { (parse_user($_[0]->src))[0] },
 );
 
-has 'src_user' => (  is => 'ro', lazy => 1,
-  default   => sub { (parse_user($_[0]->src))[1] },
+has 'src_user' => (  
+  lazy => 1,
+
+  is  => 'rwp',
+
   predicate => 'has_src_user',
-  writer    => '_set_src_user',
+
+  default   => sub { (parse_user($_[0]->src))[1] },
 );
 
-has 'src_host' => (  is => 'ro', lazy => 1,
-  default   => sub { (parse_user($_[0]->src))[2] },
+has 'src_host' => (
+  lazy => 1,
+
+  is  => 'rwp',
+
   predicate => 'has_src_host',
-  writer    => '_set_src_host',
+
+  default   => sub { (parse_user($_[0]->src))[2] },
 );
 
 1;
