@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Alarmclock;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 use 5.10.1;
 use strict;
@@ -7,7 +7,7 @@ use warnings;
 
 use Bot::Cobalt;
 
-use Bot::Cobalt::Utils qw/ timestr_to_secs rplprintf /;
+use Bot::Cobalt::Utils qw/ timestr_to_secs /;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
@@ -39,7 +39,7 @@ sub Cobalt_unregister {
 
   logger->info("Unregistering core IRC plugin");
 
-  $core->timer_del_alias( $core->get_plugin_alias($self) );
+  core()->timer_del_alias( core()->get_plugin_alias($self) );
 
   return PLUGIN_EAT_NONE
 }
@@ -54,7 +54,7 @@ sub Bot_executed_timer {
     unless exists $self->{Active}->{$timerid};
   
   logger->debug("clearing timer state for $timerid")
-    if $core->debug > 1;  
+    if core()->debug > 1;  
 
   delete $self->{Active}->{$timerid};
 
@@ -70,7 +70,7 @@ sub Bot_public_cmd_alarmdel {
   my $context = $msg->context;
   my $nick    = $msg->src_nick;
   
-  my $auth_usr = $core->auth->username($context, $nick);
+  my $auth_usr = core()->auth->username($context, $nick);
   return PLUGIN_EAT_NONE unless $auth_usr;
 
   my $timerid = $msg->message_array->[0];
@@ -80,10 +80,12 @@ sub Bot_public_cmd_alarmdel {
   
   unless (exists $self->{Active}->{$timerid}) {
     broadcast( 'message', $context, $channel,
-      rplprintf( $core->lang->{ALARMCLOCK_NOSUCH},
-        { nick => $nick, timerid => $timerid },
+      core->rpl( q{ALARMCLOCK_NOSUCH},
+        nick    => $nick, 
+        timerid => $timerid,
       )
     );
+
     return PLUGIN_EAT_ALL
   }
   
@@ -93,13 +95,14 @@ sub Bot_public_cmd_alarmdel {
   
   ## ... did this user set this timer?
   unless ($ctxt_set eq $context && $auth_usr eq $ctxt_by) {
-    my $auth_lev = $core->auth->level($context, $nick);
+    my $auth_lev = core()->auth->level($context, $nick);
 
     ## superusers can override:
     unless ($auth_lev == 9999) {
       broadcast( 'message', $context, $channel,
-        rplprintf( $core->lang->{ALARMCLOCK_NOTYOURS},
-          { nick => $nick, timerid => $timerid },
+        core->rpl( q{ALARMCLOCK_NOTYOURS},
+          nick    => $nick, 
+          timerid => $timerid,
         )
       );
 
@@ -107,12 +110,13 @@ sub Bot_public_cmd_alarmdel {
     }
   }
   
-  $core->timer_del($timerid);
+  core()->timer_del($timerid);
   delete $self->{Active}->{$timerid};
   
   broadcast( 'message', $context, $channel,
-    rplprintf( $core->lang->{ALARMCLOCK_DELETED},
-      { nick => $nick, timerid => $timerid },
+    core->rpl( q{ALARMCLOCK_DELETED},
+      nick    => $nick, 
+      timerid => $timerid,
     )
   );
 
@@ -127,14 +131,15 @@ sub Bot_public_cmd_alarmclock {
   my $context = $msg->context;
   my $setter  = $msg->src_nick;
 
-  my $cfg = $core->get_plugin_cfg( $self );
+  my $cfg = plugin_cfg( $self );
+
   my $minlevel = $cfg->{PluginOpts}->{LevelRequired} // 1;
 
   ## quietly do nothing for unauthorized users
   return PLUGIN_EAT_NONE 
-    unless $core->auth->level($context, $setter) >= $minlevel;
+    unless core()->auth->level($context, $setter) >= $minlevel;
 
-  my $auth_usr = $core->auth->username($context, $setter);
+  my $auth_usr = core()->auth->username($context, $setter);
 
   ## This is the array of (format-stripped) args to the _public_cmd_
   my $args = $msg->message_array;
@@ -149,29 +154,27 @@ sub Bot_public_cmd_alarmclock {
   my $secs = timestr_to_secs($timestr) || 1;
   my $channel = $msg->channel;
 
-  my $id = $core->timer_set( $secs,
+  my $id = core()->timer_set( $secs,
     {
       Type => 'msg',
       Context => $context,
       Target => $channel,
       Text   => $txtstr,
-      Alias  => $core->get_plugin_alias($self),
+      Alias  => plugin_alias($self),
     }
   );
 
   my $resp;
   if ($id) {
     $self->{Active}->{$id} = [ $context, $auth_usr ];
-    $resp = rplprintf( $core->lang->{ALARMCLOCK_SET},
-      {
+    $resp = core->rpl( q{ALARMCLOCK_SET},
         nick => $setter,
         secs => $secs,
         timerid => $id,
         timestr => $timestr,
-      }
     );
   } else {
-    $resp = rplprintf( $core->lang->{RPL_TIMER_ERR} );
+    $resp = core->rpl( q{RPL_TIMER_ERR} );
   }
 
   if ($resp) {
