@@ -1,7 +1,5 @@
 package Bot::Cobalt::Plugin::Extras::DNS;
-our $VERSION = '0.011';
-
-## Mostly borrowed from POE::Component::IRC::Plugin::QueryDNS by BinGOs
+our $VERSION = '0.012';
 
 use 5.10.1;
 
@@ -9,13 +7,10 @@ use Bot::Cobalt;
 use Bot::Cobalt::Common;
 
 use POE;
-use POE::Component::Client::DNS;
 
 use Net::IP::Minimal qw/ip_is_ipv4 ip_is_ipv6/;
 
-sub RESOLVER () { 0 }
-
-sub new { bless [undef], shift }
+sub new { bless [], shift }
 
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
@@ -72,11 +67,7 @@ sub _start {
 
   $kernel->alias_set( 'p_'. core()->get_plugin_alias($self) );
 
-  $self->[RESOLVER] = POE::Component::Client::DNS->spawn(
-    Alias => 'named'. core()->get_plugin_alias($self),
-  );
-
-  logger->debug("Resolver session spawned");
+  logger->debug("Resolver-handling session spawned");
 }
 
 sub dns_resp_recv {
@@ -148,7 +139,7 @@ sub dns_issue_query {
   my ($self, $kernel) = @_[OBJECT, KERNEL];
   my ($context, $channel, $host, $type) = @_[ARG0 .. $#_];
  
-  my $resp = $self->[RESOLVER]->resolve(
+  my $resp = core()->resolver->resolve(
     event => 'dns_resp_recv',
     host  => $host,
     type  => $type,
